[][src]Module streamson_lib::handler

Collections of handler (what to do with matched paths and data).

Re-exports

pub use analyser::Analyser;
pub use buffer::Buffer;
pub use file::File;
pub use indexer::Indexer;
pub use println::PrintLn;
pub use replace::Replace;
pub use shorten::Shorten;

Modules

analyser

Handler which stores matched paths

buffer

Handler which buffers output which can be manually extracted

file

Handler which puts output into a file

indexer

Handler which stores indexes where matched data are kept. The data should be within <start_idx, end_idx) range

println

Handler which puts output into stdout

replace

Handler which replaces output by fixed data it can be used e.g. to clear the sensitive data "secred_password" -> `"***"

shorten

Handler which shortens matched data it can be used e.g. shorten long strings "some long text" -> "some lon..."

Traits

Handler

Common handler trait